
# REST API

## Get Started

This is the REST API for the CICD server. It is used to interact with the server.
Users should follow the client doc or dev-docs to install the required packages.
Database setup is required to run the server.

### How to start the server

```
poetry run cicd-server
```

### How to see the API docs
To see the API docs, start the server and then open your browser and navigate to:

http://127.0.0.1:5000/apidocs

Users can interact with the webpage to send requests and see sample responses.

A quick view of the API endpoints is shown below:
![API Endpoints](../../../images/API_docs.jpg)


